#!/bin/sh

### Tunable Parameters
#
# MODE - Run demo in simulation or normal mode
#

MODE="normal"
#MODE="simulation"

#
# Specifies the number of beacons being calibrated.
#

NUMBEACONS=4

#
# If not set to 0, BEACONSELECT filters out beacons
# that are not specified in the comma-delimited list of
# beacon identifiers:
#
# space1%id1,space2%id2,...
#
# where each beacon identifier is defined by a space string
# and a id number (Currently, id should always be set to 0).  
# NUMBEACONS will be overridden by the
# number of elements in this list.
#
# BEACONSELECT is useful in situations where many beacons 
# are deployed but you only want to run the BeaconConfig 
# demo using a subset of those beacons.  
#
# Set BEACONSELECT to 0 if you want it disabled.
#

BEACONSELECT=0
#BEACONSELECT=A%32,B%32,D%32 

#
# CRICKETD_IP_ADDR specifies the ip location of cricketd (aka gpsd).
# Use 127.0.0.1 for localhost.
#

CRICKETD_IP_ADDR=10.0.0.100
#CRICKETD_IP_ADDR=127.0.0.1

#
# Uncomment the following to enable raw CRICKETD output from CricketDaemon
# (Useful for debugging!)
#

CRICKETD_PRINT_ENABLE="-r"

#
# Uncomment the following to enable connection with BeaconConfigRemote.
# If the following is uncommented AND no BeaconConfigRemote connects
# to the local BeaconConfig program, the GUI may "hang" due to network
# timeouts.
#

REMOTE_ENABLE="-r"

#
# Beacons with fewer than ENOUGHSAMPLES within FILTER_WINDOW_MS window
# are ignored.  This is useful to filter invalid beacons as a result of
# noise generated by poor serial port connections or RF errors that
# corrupt the beacon information.  Usually, a value of 2-3 is enough for
# effective filtering. This filter has no effect on the accuracy of the 
# distance measurement between a beacon and a listener.
#

ENOUGHSAMPLES=2

#
# This defines the maximum beacon-listener separation distance during
# calibration.  That is, the listener must be held within SEPDIST_CM cm
# directly below a beacon during calibration.  When SEPDIST_CM is large
# relative to the distances between beacons (1.5x or greater), the user
# should move swiftly from one beacon to another during the calibration
# process.  Otherwise, BeaconConfig might start a measurement while 
# the listener is not directly underneath a beacon and cause errors
# in the beacon coordinate computation.
# 

SEPDIST_CM=5000

#
# STDDEV_TOLERANCE_CM is a threshold value expressed in (cm)
# This value is used to define
#
# 1) The threshold for determining a stable distance measurement during
#    the calibration phase.  A distance measurement is "stable" when 
#    the stddev value of the distances collected over 
#    the last FILTER_WINDOW_MS ms falls below STDDEV_TOLERANCE_CM.
#
#
# The recommended value for Cricket v1 is 15 and for Cricket v2 10 cm.
#

STDDEV_TOLERANCE_CM=10

#
# Size of history window in milliseconds. For Cricket v1, the recommended
# value is 15000.  For Cricket v2, the recommended value is 4000.  In all 
# cases, the mode value of the distances collected in the history window 
# is used to estimate the true distance between a beacon and the listener.
#

FILTER_WINDOW_MS=4000

#
# Size of the GUI window in pixels (x,y-dimension ~ WIN_SIZE_PIX x WIN_SIZE_PIX)
#

WIN_SIZE_PIX=500

#
# The following specification is deprecated.  Now MAXCOORD
# just specifies the initial coordinate system size as described
# below.  If any of the beacon coordinates lie outside of this
# coordinate system, BeaconConfig now re-scales the coordinate system
# so that all of the beacons will show within the window.
#
# MAXCOORD specifies the size of the coordinate system in cm.
# Express coordinate boundary as (x1,y1,x2,y2), where (x1,y1) 
# is the lower left hand corner coordinate and (x2,y2) is the 
# upper right hand corner. Then setting the MAXCOORD value below 
# defines the screen coordinates with boundaries
# (-MAXCOORD, -MAXCOORD, +MAXCOORD, +MAXCOORD).  The (0,0) origin is 
# in the center of the screen.  MAXCOORD is in units of cm.  
# So if MAXCOORD=400, you get a 8m x 8m area.  The scale of 
# true-to-life distance to screen pixels will thus be
#
#   (2*MAXCOORD)/WIN_SIZE_PIX  ( units: cm/screen_pixel )
#

MAXCOORD=100

#
# GUI grid size in cm (61cm ~ 2ft).   The GUI will automatically 
# adjust the drawing scale so the size of the grid as appear on the 
# screen may vary.
#

GRID_SIZE_CM=61

#
# The size of the sample monitor history window (ms) and the max value 
# for the y-axis (cm).
#

SAMPLEMONHISTORY_MS=5000
SAMPLEMONMAXY_CM=400

#
# Streamer draws the trail of the cricket listener during tracking mode.
#
# Set to 0 to disable streamer.  Otherwise, STREAMERSAMPLINGPERIOD
# defines the density of the streamer (smaller period will draw more 
# dots per time unit for the trail).  STREAMERDELAY defines how
# long the trail dots stay on the screen before disappearing.
#

STREAMERSAMPLINGPERIOD_MS=50
STREAMERDELAY_MS=3000

#
# Uncommenting the following will enable Sun's Java HotSpot Server mode.
# The jvm will perform dynamic compiling to increase performance.
# However, the start up time will be quite slow.
# In general, the applications will run sluggishly in the first minute or
# so (depending on the computer speed) until the compilation is
# complete.  After the first minute, the CPU load should drop
# significantly.
#

JAVAHOTSPOT_ENABLE="-server"

#
# For hard coding beacon coordinates, please see beacons.conf file.
# After BeaconConfigDemo app launches, click on Override button
# to load the hardcodeded coordinates.
#
############################################# End of Tunable Params


if [ "$OS" = "Windows_NT" ]
then SEP=";"
else SEP=":"
fi

LIB=""
#LIB="../lib/"

CLASSPATH=".${SEP}${LIB}plot.jar${SEP}samplemon.jar${SEP}beaconfinder.jar${SEP}beaconconfig.jar${SEP}cricketdaemon.jar${SEP}${LIB}Jama-1.0.1.jar${SEP}viewfinder.jar${SEP}${LIB}gnu.getopt.jar"

## Launch BeaconFinderApp
java $JAVAHOTSPOT -cp $CLASSPATH beaconfinder.BeaconFinderApp \
    -s$STDDEV_TOLERANCE_CM -H$SAMPLEMONHISTORY_MS -y$SAMPLEMONMAXY_CM &

if [ "$MODE" = "simulation" ]
then 
SEPDIST_CM=80
fi

## Launch BeaconConfig
java $JAVAHOTSPOT -cp $CLASSPATH beaconconfig.BeaconConfig -e$ENOUGHSAMPLES \
    -n$NUMBEACONS -c$SEPDIST_CM -s$STDDEV_TOLERANCE_CM -W$WIN_SIZE_PIX \
    -w$MAXCOORD -g$GRID_SIZE_CM $REMOTE_ENABLE \
    -d$STREAMERDELAY_MS -t$STREAMERSAMPLINGPERIOD_MS \
    -B $BEACONSELECT &

## Launch CricketDaemon
if [ "$MODE" = "simulation" ]
then 
echo ">>>>>>>>>>> Simulation Mode";
java $JAVAHOTSPOT -cp $CLASSPATH cricketdaemon.CricketDaemon -P \
-s -S$FILTER_WINDOW_MS -e$ENOUGHSAMPLES -t$STDDEV_TOLERANCE_CM
else 
echo ">>>>>>>>>>> Normal Mode";
java $JAVAHOTSPOT -cp $CLASSPATH cricketdaemon.CricketDaemon -P \
-g$CRICKETD_IP_ADDR -S$FILTER_WINDOW_MS -e$ENOUGHSAMPLES \
-t$STDDEV_TOLERANCE_CM $CRICKETD_PRINT_ENABLE
fi


# debugging flags
# use jdb attach jdbconn
#DEBUG="-Xdebug -Xrunjdwp:transport=dt_shmem,address=8000,server=y,suspend=n"
#DEBUG=
#java $JAVAHOTSPOT -cp $CLASSPATH cricketdaemon.CricketDaemon -P\
#-g$CRICKETD_IP_ADDR -S$FILTER_WINDOW_MS -e$ENOUGHSAMPLES
#jdb -classpath $CLASSPATH cricketdaemon.CricketDaemon
