/*    
       This software may be used and distributed according to the terms of
       the GNU General Public License (GPL), incorporated herein by
       reference.  Drivers based on this skeleton fall under the GPL and
       must retain the authorship (implicit copyright) notice.
 
       This program is distributed in the hope that it will be useful, but
       WITHOUT ANY WARRANTY; without even the implied warranty of
       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
       General Public License for more details.
 */
package cricketdaemon.reader.parse;

/**
 * Interface to support customizable routines for parsing field values.
 *
 * @author Allen Miu
 */
public interface FieldParser 
{
    /**
     * Implements the routine that parses the value of the
     * field type represented by the FieldParser.  The input
     * is a byte array representing the entire beacon, the offset
     * of the byte array at which the value of the field begins, 
     * and the length of the field.  Returns the Object 
     * representing the parsed data field.
     *
     * Byte ordering:  LSB ... MSB
     */
    // some wierd Java property: cannot override static methods!
    public Object parse(byte[] beacon, int offset, int length);

    /**
     * The inverse function of <code>parse()</code>. 
     *
     * @see FieldParser#parse
     */
    public byte[] unparse(Object o);

    /**
     * Converts the <code>toString()</code> representation of the
     * <code>Object</code> returned by <code>parse()</code> into the
     * original Object.  The relationship between the
     * <code>Object</code> and <code>stringToReturnType</code> is akin to,
     * for example, <code>Integer</code> and <code>Integer.valueOf()</code>.
     */
    public Object stringToReturnType(String o);
    
    /**
     * Same as <code>stringToReturnType()</code> except o takes the
     * format of the values returned by GPSD.  
     */
    public Object GPSDStringToReturnType(String o);
}
